Trait MaybeSync

pub trait MaybeSync: Sync { }
Sync on native targets; no bound on web (where there’s only one thread).

Use this in generic bounds that need Sync on native but should compile on web without the bound.

Implementors

Source

impl<T: Sync> MaybeSync for T